pub struct BundleSettings {Show 24 fields
pub identifier: Option<String>,
pub publisher: Option<String>,
pub homepage: Option<String>,
pub icon: Option<Vec<String>>,
pub resources: Option<Vec<String>>,
pub resources_map: Option<HashMap<String, String>>,
pub copyright: Option<String>,
pub license: Option<String>,
pub license_file: Option<PathBuf>,
pub category: Option<AppCategory>,
pub file_associations: Option<Vec<FileAssociation>>,
pub short_description: Option<String>,
pub long_description: Option<String>,
pub bin: Option<HashMap<String, BundleSettings>>,
pub external_bin: Option<Vec<String>>,
pub deep_link_protocols: Option<Vec<DeepLinkProtocol>>,
pub deb: DebianSettings,
pub appimage: AppImageSettings,
pub rpm: RpmSettings,
pub dmg: DmgSettings,
pub ios: IosSettings,
pub macos: MacOsSettings,
pub updater: Option<UpdaterSettings>,
pub windows: WindowsSettings,
}Expand description
The bundle settings of the BuildArtifact we’re bundling.
Fields
identifier: Option<String>the app’s identifier.
publisher: Option<String>The app’s publisher. Defaults to the second element in the identifier string.
Currently maps to the Manufacturer property of the Windows Installer and the Maintainer field of debian packages if the Cargo.toml does not have the authors field.
homepage: Option<String>A url to the home page of your application. If None, will fallback to PackageSettings::homepage.
Supported bundle targets: deb, rpm, nsis and msi
icon: Option<Vec<String>>the app’s icon list.
resources: Option<Vec<String>>the app’s resources to bundle.
each item can be a path to a file or a path to a folder.
supports glob patterns.
resources_map: Option<HashMap<String, String>>The app’s resources to bundle. Takes precedence over Self::resources when specified.
Maps each resource path to its target directory in the bundle resources directory.
Supports glob patterns.
copyright: Option<String>the app’s copyright.
license: Option<String>The package’s license identifier to be included in the appropriate bundles. If not set, defaults to the license from the Cargo.toml file.
license_file: Option<PathBuf>The path to the license file to be included in the appropriate bundles.
category: Option<AppCategory>the app’s category.
file_associations: Option<Vec<FileAssociation>>the file associations
short_description: Option<String>the app’s short description.
long_description: Option<String>the app’s long description.
bin: Option<HashMap<String, BundleSettings>>Configuration map for the apps to bundle.
external_bin: Option<Vec<String>>External binaries to add to the bundle.
Note that each binary name should have the target platform’s target triple appended,
as well as .exe for Windows.
For example, if you’re bundling a sidecar called sqlite3, the bundler expects
a binary named sqlite3-x86_64-unknown-linux-gnu on linux,
and sqlite3-x86_64-pc-windows-gnu.exe on windows.
Run tauri build --help for more info on targets.
If you are building a universal binary for MacOS, the bundler expects
your external binary to also be universal, and named after the target triple,
e.g. sqlite3-universal-apple-darwin. See
https://developer.apple.com/documentation/apple-silicon/building-a-universal-macos-binary
deep_link_protocols: Option<Vec<DeepLinkProtocol>>Deep-link protocols.
deb: DebianSettingsDebian-specific settings.
appimage: AppImageSettingsAppImage-specific settings.
rpm: RpmSettingsRpm-specific settings.
dmg: DmgSettingsDMG-specific settings.
ios: IosSettingsiOS-specific settings.
macos: MacOsSettingsMacOS-specific settings.
updater: Option<UpdaterSettings>Updater configuration.
windows: WindowsSettingsWindows-specific settings.